# RITAS Changelog

## ritas 0.1.1 Release (20 Feb 2024)

Hopefully a clean release ready for pypi and conda-forge.  Infrastructure
improvements with this release.

## ritas 0.1.0 Release (19 Feb 2024)

Initial project release, with a soon followup to release to PyPI and eventually
conda-forge.

### API Changes

None.

### New Features

None.

### Bug Fixes

None.
